% Compare Model 2 and Model 1


clear all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Load Model 2 %%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load Model2.mat

m2_bhat=bhat;
m2_what=what;
m2_fhat=fhat;

clearvars -except m2_bhat m2_what m2_fhat

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Load Model 1 %%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load Model1.mat
m1_bhat=bhat;
m1_what=what;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Define base values %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

parameter={'$\lambda$', '$\alpha^+$','$\beta^+$', '$\alpha^-$','$\beta^-$','$\sigma$' };
parameter_name={'lambda','alpha_plus','beta_plus','alpha_minus','beta_minus','sigma'};
base(1,:)=linspace(0.01,10);
base(2,:)=linspace(0.01,2);
base(3,:)=linspace(0.01,2);
base(4,:)=linspace(0.01,2);
base(5,:)=linspace(0.01,2);
base(6,:)=linspace(0.002,0.4);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Plot distributions %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% Plot one figure for each distribution

for k=1:6
   figure 
    x=base(k,:);
    % Plot Model0
y=lognpdf(x,m1_bhat(k,1),sqrt(m1_what(k,1)));
h0=plot(x,y,'-');
set(h0,'linewidth',2,'color',[254 127 14]./255);
hold on

    % Plot Model1
y=lognpdf(x,m2_bhat(k,1),sqrt(m2_what(k,1)));
h0=plot(x,y,'-');
set(h0,'linewidth',2,'color',[31 119 180]./255);
name1=[char(parameter(k)  ) char(' : country effect')];
name2=[char(parameter(k)  ) char(' : macro indicators')];
legend(name1, name2);
set(legend,'interpreter','latex','fontsize',16);

name3=[ char('model1vs2_') char(parameter_name(k)  )];

   saveas(gcf,name3,'epsc')
 close
end

figure

% Plot one figure for all distributions
for k=1:6
    subplot(3,2,k)
    x=base(k,:);
    % Plot Model0
y=lognpdf(x,m1_bhat(k,1),sqrt(m1_what(k,1)));
h0=plot(x,y,'-');
set(h0,'linewidth',2,'color',[254 127 14]./255);
hold on

    % Plot Model1
y=lognpdf(x,m2_bhat(k,1),sqrt(m2_what(k,1)));
h0=plot(x,y,'-');
set(h0,'linewidth',2,'color',[31 119 180]./255);
name1=[char(parameter(k)  ) char(' : country effect')];
name2=[char(parameter(k)  ) char(' : macro indicators')];
legend(name1, name2);
set(legend,'interpreter','latex','fontsize',16);


end
