function eta=MVR(MU,SIGMA,draws)
% function eta=MVR(MU,SIGMA,draws)
%
% Transform normal iid draws in multivariate draws
% MU:       mean, row vector
% SIGMA:    variance-covariance matrix
% draws:    N normal iid draws: N  x K matrix
%
% Example: draws a sequence of 1000 Halton draws for 3 parameters
% draws=makedraws2(1000,3,1,3);
% draws=permute(draws,[1,3,2]);
% MU=[.5 12 -4];
% SIGMA=[.4 .23 0;.23 2 0; 0 0 .1];

try
% Cholesky decomposition
L = chol(SIGMA,'lower');
% compute multivariate values
eta=(L*draws')'+repmat(MU',size(draws,1),1);
catch
% compute multivariate values
eta=repmat(abs(MU'*0),size(draws,1),1);
    
%L=nan*SIGMA; 
disp('Catch Called, unable to perform Cholesky decomposition, replace unobs by Zeros');
end


