function MSL(handles)

% Based on K. Train estimation routine
% Inspired by the code written by Kenneth Train, July 2006

% This version, October 22, 2014
% Declare Globals
global Gains Losses Mixed Type
%global Probit
global Choice_Gains Choice_Losses Choice_Mixed COVARIATES
global NV NF IDV IDF NF2
global Posit
global draws
global CEorValues
global Heteroskedastic Var_TrembNoi Fix_TrembNoi Sign_TrembNoi
global Fixed_TN
global Index_Gains Index_Losses Index_Mixed
global Final


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %    
%                           SETTINGS                                    %
%                                                                       %    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
No_Random=0; % to compare with the basic stata output

Test_parfor=0; % to compare parrallel computing and brute force, done on model 1 with female only

% Number of draws from to use per person in simulation.
try
NDRAWS=str2num(handles.Halton);
catch
NDRAWS=500;
end

if No_Random
    NDRAWS=1;
end

if Test_parfor
NDRAWS=1000;
end

NDRAWS=1000;

% DECISON MODEL 
% Type: 1 Prospect Theory
%       2 Reference Dependence
%       3 Expected Utility
%       4 Yaari (sign dependent)
Type=handles.Type;


% Link model
Probit=handles.Probit;

% Difference in values or difference in CE
if handles.CEorValues
CEorValues='Values';
else
CEorValues='CE';    
end

% Heteroskedasticity a la Bruhin et al. (2010)
if handles.Heteroskedastic
Heteroskedastic=1;
end

% Heterogenous noise/tremble variable
Var_TrembNoi='Noise';
%Var_TrembNoi='Tremble';

% Homogenous noise/tremble variable
%Fix_TrembNoi='Noise';
%Fix_TrembNoi='Tremble';
%Fix_TrembNoi=[];
Fix_TrembNoi='Noise_losses';


% Sign-dependent noise/tremble variable
%Sign_TrembNoi=1;
Sign_TrembNoi=handles.Sign_TrembNoi;
% if EU, can't be sign-dependent
if Type==3
Sign_TrembNoi=0;
end  

% TITLE
% Put a title for the run in the quotes below, to be printed at the top of the output file.
switch Type
    case 1
        MD='Prospect Theory';
    case 2
        MD='Reference Dependence';
    case 3
        MD='Expected Utility';
    case 4
        MD='Yaari (sign-dependent)';
end
      
disp(' ')
disp(['MSL Algorithm: ' num2str(NDRAWS) ' Halton draws, Decision Model is ' MD '.']);
disp(' ')




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %    
%                                 DATA                                  %
%                                                                       %    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Load Certainty_Equivalent Matrix
load('Certainty_Equivalents.mat');  %The variables are described below

% For the purpose of testing the program, it is possible to restrict the
% number of subjects here
country=handles.Country;

% In case we just have one country, then remove the others
if size(country,2)<2
Choice_Gains(:,COV(:,country)==0)=[];
Choice_Losses(:,COV(:,country)==0)=[];
Choice_Mixed(:,COV(:,country)==0)=[];
COV(COV(:,country)==0,:)=[];
end

% To remove 10% of the subject for robustness
% temp=randperm(size(Choice_Gains,2));
% temp=temp(1:300);
% Choice_Gains(:,temp)=[];
% Choice_Losses(:,temp)=[];
% Choice_Mixed(:,temp)=[];


% Number of people (decision-makers) in dataset 
NP=size(Choice_Gains,2);        

% Number of choice situations in dataset. This is the number faced by all the people combined.
% Depend on size of data
NCS=size(Choice_Gains,1)+size(Choice_Losses,1)+size(Choice_Mixed,1);     

Index_Gains=1:size(Gains,1);
Index_Losses=max(Index_Gains)+(1:size(Losses,1));
Index_Mixed=max(Index_Losses)+(1:size(Mixed,1));

% Total number of alternatives faced by all people in all choice situations combined.
% This is the number of rows of data in XMAT below.
NROWS=NCS.*1;


% This dataset is for people's choice among loteries in a cross-country 
% experiment. Each person faced up to N experiments (some faced fewer
% than N because they did not complete all the experiments.) Each
% experiment contained 2 alternatives representing one uncertain option and one safe, sure option.
% The person stated which of the two option he/she would take if facing this choice for real 
% The certainty equivalent corresponds to the switching point between the 2
% options. Because one option is fixed and the other is variable, the
% switching point describes the choice within each list.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %    
%                        MODEL SPECIFICATION                            %
%                                                                       %    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% RANDOM COEFFICIENTS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% List the preference parameters that enter the model with random coefficients and
% give the distribution for the coefficient of each variable.

% IDV contains one row for each random coefficient and two columns.
% The *first* column specifies the distribution of the coefficient for that variable.

% The distributions can be 
% 1. normal: N(b,w) where mean b and standard deviation w are estimated.
% 2. lognormal: coefficient is exp(beta) where beta~N(b,w) with b and w estimated
% 3. truncated normal, with the share below zero massed at zero: max(0,beta) where 
%                      beta~N(b,w) with b and w estimated.
% 4. S_B: exp(beta)/(1+exp(beta))  where beta~N(b,w) with b and w estimated.
% If no random coefficients, put IDV=[];

% Give a name to each of the explanatory variables in IDV. They can 
% have up to ten characters including spaces. Put the names in single quotes and separate 
% the quotes with semicolons. If IDV=[], then set NAMES=[];


if Type==3
IDV=[ 1;   ...  % utility parameter
      4;   ...  % tremble
      ];
  NAMES={'Utility parameter';'Tremble'}; 

else
    if Type==1
IDV=[ 1;   ...  % utility parameter gains
      1;   ...  % utility parameter losses
      2;   ...  % loss aversion
      2;   ...  % Prelec pwf gains
      2;   ...  % Prelec pwf gains
      2;   ...  % Prelec pwf losses
      2;   ...  % Prelec pwf losses
      4;   ...  % tremble
      ];     
  NAMES={'Utility parameter (Gains)';'Utility parameter (Losses)';'Loss Aversion';...
      'Prelec param 1 (Gains)';'Prelec param 2 (Gains)';'Prelec param 1 (Losses)';...
      'Prelec param 2 (Losses)';'Tremble'}; 
    elseif Type==2
        IDV=[ 1;   ...  % utility parameter gains
      1;   ...  % utility parameter losses
      2;   ...  % loss aversion
      4;   ...  % tremble
      ];     
   NAMES={'Utility parameter (Gains)';'Utility parameter (Losses)';'Loss Aversion';...
     'Tremble'}; 
    elseif Type==4
IDV=[ 2;   ...  % loss aversion
      2;   ...  % Prelec pwf gains
      2;   ...  % Prelec pwf gains
      2;   ...  % Prelec pwf losses
      2;   ...  % Prelec pwf losses
      4;   ...  % tremble
      ];     
  NAMES={'Loss Aversion';...
      'Prelec param 1 (Gains)';'Prelec param 2 (Gains)';'Prelec param 1 (Losses)';...
      'Prelec param 2 (Losses)';'Tremble'}; 
    end
  
if Sign_TrembNoi==1
    IDV=[IDV;   ...  % Previous
           4;   ...  % tremble losses
           4;   ...  % tremble mixed
        ];
    NAMES{end}='Tremble (Gains)';
    NAMES{end+1}='Tremble (Losses)';
    NAMES{end+1}='Tremble (Mixed)';
elseif Sign_TrembNoi==2
    IDV=[IDV;   ...  % Previous
        % October 2014 in Berlin
        %   4;   ...  % tremble losses
        ];
    NAMES{end}='Tremble (Gains)';
   % NAMES{end+1}='Tremble (Losses)';    
end
end

NV=size(IDV,1); %Number of random coefficients. Do not change this line.


% if the variable Homogenous_Noise is set to 0, the Noise parameter replaces the Tremble parameter
% as a Random coefficient

if strcmp(Var_TrembNoi,'Noise')
    IDV(end,1)=2;
    NAMES{end}='Noise';
    if Sign_TrembNoi==1
       IDV((end-2):end,1)=2;
    NAMES{end-2}='Noise (Gains)';
    NAMES{end-1}='Noise (Losses)';
    NAMES{end}='Noise (Mixed)';
    elseif Sign_TrembNoi==2
       IDV((end-1):end,1)=2;
    %NAMES{end-1}='Noise (Gains)';
    %NAMES{end}='Noise (Losses)';
    NAMES{end}='Noise ';
    end
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Starting values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Specify the starting values for b and w for each random coeffient.
% B contains the first parameter, b, for each random coefficient.  
% It is a column vector with the same length as IDV. For distribution 5 (normal with zero mean),
% put 0 for the starting value for the mean. The code will keep it at 0.
% W contains the second parameter, w, for each random coefficient.
% It is a column vector with the same length as IDV.
% Put semicolons between the elements of B and W (so they will be column vectors).
% SET values as final value parameter (transformed), program will
% untransforms the values
% L is the Cholesky factor (Variance covariance= L'x L)


% October 2014 in Berlin, use base estimations as starting values
% Previous versions of the program use different starting values, see these
% versions for alternatives
B=[0.71 -0.40 -0.05 -0.29 -0.04 -1.93]';
W=[0.15 0.18 0.13 0.17 0.12 0.22]';
F_temp=[];

if handles.MODEL==4
   load Starting_values_M34 
   B=B_34;
   W=W_34;
elseif handles.MODEL==7
     load Starting_values_M2 
   B=B_2;
   W=W_2;
end

% Transform initial variance-covariance matrix of random effect to Cholesky
% factor:
temp=W;
W=nan(size(B,1));
W(logical(eye(size(W))))=temp;
W(isnan(W))=0;
temp=diag(chol(W,'lower'));
L=nan(size(B,1));
L(logical(eye(size(L))))=temp;
clear temp

if handles.MODEL==7
    % allows non diagonal elements
L=tril(L,0);
end


% Add noise parameter to the set of random effects
% See previous version of the program for this possibility

% Initial values for tremble/noise when homogenous
if any(Fix_TrembNoi)
    Fixed_TN=B*nan;
    if strcmp(Fix_TrembNoi,'Tremble')   % Starting value of homogenous tremble
        Fixed_TN(1)=0.01;
       Fixed_TN=log(Fixed_TN)./(1-Fixed_TN);    % Map initial value of Tremble to [-inf,inf]
    elseif strcmp(Fix_TrembNoi,'Noise')  % Starting value of homogenous noise
        if Heteroskedastic
            Fixed_TN(1)=1./20;
        else
        Fixed_TN(1)=1;
        end
        Fixed_TN=log(Fixed_TN);                 % Map initial value of Noise to [-inf,inf]
    elseif strcmp(Fix_TrembNoi,'Noise_losses')  % Starting value of loss-specific noise
        Fixed_TN(1)=0.02;
    else
        Fixed_TN=[];
    end
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                
% FIXED COEFFICIENTS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% List the variables that enter with fixed coefficients.
% Put semicolons between the numbers.
% If no fixed coefficients, put IDF=[];

% No fixed Coefficients on Tremble/Noise
if Sign_TrembNoi==1
    NV_F=NV-3;   
elseif Sign_TrembNoi==2
%   NV_F=NV-2; 
    NV_F=NV;    
else
    NV_F=NV-1;
end


% First, list all possibilities, before selecting the relevant ones
% depending on the version of the program

% Countries, base = USA (number 41)
range=[13:40 42];
temp=bsxfun(@times,range,ones(1,NV_F)');
Country_F=temp;
Country_IDF(:,1)=temp(:);
temp=bsxfun(@times,range*0+1,(1:NV_F)');
Country_IDF(:,2)=temp(:);
Country_NAMES={'Australia' 'Belgium' 'Brazil' 'Cambodia' 'Chile' 'China' 'Colombia' 'Costarica' 'Czech' 'Ethiopia' 'France' 'Germany' 'Guatemala' 'India' ' Japan' 'Kyrgyzstan' 'Malaysia' 'Nicaragua' 'Nigeria' 'Peru' 'Poland' 'Russia' 'Saudi' 'Southafrica' 'Spain' 'Thailand'  'Tunisia' 'UK' 'Vietnam'};
Fixed_NAMES(1,range)=Country_NAMES;
clear temp

% Income
range=66:71;
temp=bsxfun(@times,range,ones(1,NV_F)');
Income_F=temp;
Income_IDF(:,1)=temp(:);
temp=bsxfun(@times,range*0+1,(1:NV_F)');
Income_IDF(:,2)=temp(:);
Income_NAMES={'gdp_diff' 'log_exp_z' 'foreigner' 'gini_z' 'private' 'opec'};
Fixed_NAMES(1,range)=Income_NAMES;
clear temp

% Macro
range=[66 69:71];
temp=bsxfun(@times,range,ones(1,NV_F)');
Macro_F=temp;
Macro_IDF(:,1)=temp(:);
temp=bsxfun(@times,range*0+1,(1:NV_F)');
Macro_IDF(:,2)=temp(:);
Macro_NAMES={'gdp_diff' 'gini_z' 'private' 'opec'};
Fixed_NAMES(1,range)=Macro_NAMES;
clear temp

% Personal Income
range=67;
temp=bsxfun(@times,range,ones(1,NV_F)');
PersIncome_F=temp;
PersIncome_IDF(:,1)=temp(:);
temp=bsxfun(@times,range*0+1,(1:NV_F)');
PersIncome_IDF(:,2)=temp(:);
PersIncome_NAMES={'log_exp_z'};
Fixed_NAMES(1,range)=PersIncome_NAMES;
clear temp

% Gender
range=43;
temp=bsxfun(@times,range,ones(1,NV_F)');
Gender_F=temp;
Gender_IDF(:,1)=temp(:);
temp=bsxfun(@times,range*0+1,(1:NV_F)');
Gender_IDF(:,2)=temp(:);
Gender_NAMES={'female' };
Gender_NAMES(1,range)=Gender_NAMES;
clear temp


% Physical
range=43:45;
temp=bsxfun(@times,range,ones(1,NV_F)');
Physical_F=temp;
Physical_IDF(:,1)=temp(:);
temp=bsxfun(@times,range*0+1,(1:NV_F)');
Physical_IDF(:,2)=temp(:);
Physical_NAMES={'female' 'age' 'height'};
Fixed_NAMES(1,range)=Physical_NAMES;
clear temp

% Cultural
range=46:49;
temp=bsxfun(@times,range,ones(1,NV_F)');
Cultural_F=temp;
Cultural_IDF(:,1)=temp(:);
 temp=bsxfun(@times,range*0+1,(1:NV_F)');
 Cultural_IDF(:,2)=temp(:);
Cultural_NAMES={'individualism' 'uncertainty' 'power_distance' 'masculinity'};
Fixed_NAMES(1,range)=Cultural_NAMES;
clear temp

% Religion (base=protestant)
range=50:57;
temp=bsxfun(@times,range,ones(1,NV_F)');
Religion_F=temp;
Religion_IDF(:,1)=temp(:);
 temp=bsxfun(@times,range*0+1,(1:NV_F)');
 Religion_IDF(:,2)=temp(:);
Religion_NAMES={'atheist' 'catholic' 'orthodox' 'muslim' 'jewish' 'hindu' 'buddist' 'religion_other'};
Fixed_NAMES(1,range)=Religion_NAMES;
clear temp


% GPA/Study (Base= economist)
range=[58:65];
temp=bsxfun(@times,range,ones(1,NV_F)');
Study_F=temp;
Study_IDF(:,1)=temp(:);
temp=bsxfun(@times,range*0+1,(1:NV_F)');
Study_IDF(:,2)=temp(:);
Study_NAMES={'gpa'  ' math' 'natural' 'medicine' 'social' 'humanities' 'arts' 'study_other'};
Fixed_NAMES(1,range)=Study_NAMES;
clear temp


%%%%%%%%%%%% October 2014 in Berlin, define the different versions of the models %%%%%%%%%%%%%%%

fixed_effect_cov=0;
try 
   switch handles.MODEL
       case 0                   % Model 0: no covaraites
           handles.ModelF=7;
       case 1                   % Model 1: country-fixed effects
            handles.ModelF=1;
       case 2                   % Model 2: macro indicators
            handles.ModelF=2;
       case 3                   % Model 3: main individual characteristics
             handles.ModelF=3;
       case 4                   % Model 4: all individidual characteristics
           handles.ModelF=4;
       case 5                   % Model 5: fixed effect on model'2 variance covariance matrix of random coefficients
            handles.ModelF=2;
            fixed_effect_cov=1;
       case 6
           handles.ModelF=1;    %  Model 6: fixed effect on model'1 variance covariance matrix of random coefficients
           fixed_effect_cov=1;
       case 7
           handles.ModelF=2;    % Model 7: full variance covariance matrix for Model2

   end
end


% Now, build the matrix of fixed effects

IDF=[];

% Fixed effect for 1 country
if size(country,2)<2
if handles.PhysicalF
IDF=[IDF; Physical_IDF];
F_temp=F_temp*0;
end

if handles.CulturalF
IDF=[IDF; Cultural_IDF]  ;
end

if handles.ReligionF
IDF=[IDF; Religion_IDF];  
end

if handles.StudiesF
IDF=[IDF; Study_IDF];  
end
end

% Models 1 to 5 are implicitely models for all countries

switch handles.ModelF 
    case 1
        % country dummies alone
        IDF=[Country_IDF];    
        % Control for Gender with country dummies for comparison with point
        % esitmates
        %IDF=[Gender_IDF;Country_IDF];    
    case 2
       IDF=[Gender_IDF;Macro_IDF]; 
       if Test_parfor;
                  IDF=[Gender_IDF]; 
       end
       
    case 3
        IDF=[Country_IDF;Physical_IDF;Study_IDF];  
       %IDF=[Country_IDF;Physical_IDF]; 
    case 4
       IDF=[Country_IDF;Physical_IDF;Cultural_IDF;Religion_IDF;Study_IDF];         
    case 7
        IDF=[];
    case 6
        
        %Version 1 with pers income
        %IDF=[Physical_IDF;Study_IDF;PersIncome_IDF];
        %Version 2 without pers income
        %IDF=[Physical_IDF;Study_IDF];
        

end


%Give a name to each of the variables in IDF.
for i=1:size(IDF,1)
   NAMESF{1,i}=[Fixed_NAMES{1,IDF(i,1)} ', ' NAMES{IDF(i,2),1}]; 
end


% Build matrix of covariates
try
COVARIATES=COV(:,IDF(:,1));
catch
COVARIATES=[];    
end

if any(IDF)
NF=size(unique(IDF(:,1)),1);  %Number of fixed coefficients. Do not change this line.

F=nan(NV,NF);
else
    NF=0;
    F=[];
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Starting values.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Specify the starting values for the fixed coefficients F.
% F must have the same length as B and the same number of column as IDF 
% Put semicolons between the elements related to IDF (so F will be a matrix) 
%F=[.01 ;nan];%[.0001;nan];
if any(IDF)
   for k=1:NV
    if any(IDF(IDF(:,2)==k,1)')    
    F(k,:)=IDF(IDF(:,2)==k,1)'*0; %abs(B(IDF(k,2))./20);
    end
   end   
   
   if handles.MODEL==4
    load Starting_values_M34
    F=F_34;
   end
   % Use 0.00001 as starting values for fixed
   % effects, see previous version of the program for alternative
   % specification
   F=F*0+.00001; 
   %F=repmat(B*0,1,size(IDF,1))+.01;
%F(end,:)=nan;
else
   F=[]; 
end

% Starting values for the fixed effects on variance/covariance of random
% effects
if fixed_effect_cov
F2=F;
NF2=NF;
else
F2=[];
NF2=0;
end


if No_Random
    L=[];
end%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Regroup starting values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

try    
init=[F F2 B L Fixed_TN];  
catch
    disp('Impossible to specify initial paramters')
     disp('End of the main script')
    return
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                       DRAWS                                      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Type of draws to use in simulation
% 1=pseudo-random draws
% 2=standard Halton draws
% 3=shifted and shuffled Halton draws
% 4=modified Latin hypercube sampling, shifted and shuffled 
% 5=create your own draws or supertabular draws from file

DRAWTYPE=3;

% Set seed for the random number generator.
SEED1 = 14239; 

% Memory use
% Give the number of draws that you want held in memory at one time.
% This number must be evenly divisible into the number of draws.
% That is NDRAWS./NMEM must be a positive integer.
% To hold all draws in memory at once, set NMEM=NDRAWS.
% A larger value of NMEM requires fewer reads from disc but 
% uses more memory which can slow-down the calculations and increases 
% the chance of running out of memory.
% If DRAWTYPE=5, then you must set NMEM=NDRAWS
NMEM=NDRAWS;

% If all the draws are NOT held in memory at one time (that is, if NMEM<NDRAWS), 
% then give the filename (including full path if not in the working directory)
% that you want the draws to be temporarily saved to while the code is running.
% If all draws are held in memory at one time (that is, if NMEM=NDRAWS),
% then this file will not be created. So, if NMEM=NDRAWS, you can set PUTDR=''; 
% or give a file name, whichever you find more convenient, since the name won't be used.
PUTDR='draws';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                 OPTIMIZATION                                     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Maximum number of iterations for the optimization routine.
% The code will abort after ITERMAX iterations, even if convergence has
% not been achieved. The default is 400, which is used when MAXITERS=[];
MAXITERS=[];

% Convergence criterion based on the maximum change in parameters that is considered
% to represent convergence. If all the parameters change by less than PARAMTOL 
% from one iteration to the next, then the code considers convergence to have been
% achieved. The default is 0.0001, which is used when PARAMTOL=[];
PARAMTOL=0.0001;

% Convergence criterion based on change in the log-likelihood that is
% considered to represent convergence. If the log-likelihood value changes
% less than LLTOL from one iteration to the next, then the optimization routine
% considers convergence to have been achieved. The default is 0.000001,
% which is used when LLTOL=[];
LLTOL=[.00001];


% These last lines delete the file of draws that is created when NMEM<NDRAWS
% since it is no longer needed. If you want to save it, then put % in front
% of these lines.
if NMEM<NDRAWS
    clear global MDR
    delete(PUTDR)
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                 NEW VARIABLES                                    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create variables to use in estimation
%disp('Creating data arrays for run.');
cp=1:size(Choice_Gains,2); % person

NTAKES=NDRAWS./NMEM; %This tells code how many passes through the draws are needed 

randn('state',SEED1)  %For draws from normal
rand('state',SEED1)   %For draws from uniform

%Create draws
if DRAWTYPE ~= 5
   disp('Creating draws.');
   draws=makedraws2(NDRAWS,NV,NP);   %NMEMxNPxNV  draws x persons x number of random coeffs
   if NTAKES == 1
      draws=permute(draws,[2,1,3]);   %To make NPxNDRAWSxNV number of random coefs x persons  x draws
   else 
      MDR=memmapfile(PUTDR,'Format',{'double',[NDRAWS,NP,NV],'drs'});
   end
end

% Use Cholesky factors for estimation
Final=0;


% Transpose choice matrix for slicing in parralell loops
Choice_Gains=Choice_Gains';
Choice_Losses=Choice_Losses';
Choice_Mixed=Choice_Mixed';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %    
%                            ESTIMATIION                                %
%                                                                       %    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('Start estimation');
disp('The negative of the log-likelihood is minimized,');
disp('which is the same as maximizing the log-likelihood.');
tic;
options=optimset('LargeScale','off','Display','iter',...
    'MaxFunEvals',100000,'MaxIter',MAXITERS,'TolX',PARAMTOL,'TolFun',LLTOL,'GradObj','off','UseParallel',true);
options=optimset('LargeScale','off','Display','iter',...
    'MaxFunEvals',10000000,'MaxIter',MAXITERS,'TolX',PARAMTOL,'TolFun',LLTOL);

% Input param is a column vector of parameters, dimension (NF+NF2+NV+NV)x1
%     containing the fixed coefficients, the first parameters of the random
%     coefficients, and then the second parameters of the random coefficients
% Output ll is the scalar value of the negative of the simulated log-likelihood 
%     at the input parameters

% Transform Actual parameter matrix to vector for easier post-estimation
% commands

[init_Vector,Posit]=Mat2Vect(init);

% Define estimation model
model=@(param) loglik(param);


disp(' ')
disp('Initial log-likelihood value : ')
disp(model(init_Vector));
disp(' ')
% Now, launch estimation

[paramhat,fval,exitflag,output,grad,hessian]=fminunc(model,init_Vector,options);

% Save values with a time-specific name
save_name=['MSL' datestr(now,'yymmdd')  '_' datestr(now,'HHMM') '_' MD];
save(save_name);

% Save values with the generic LastEstim name, to be recalled to save for
% each specification afterwards

save('LastEstim');

% Information about the estimation
disp(' ');
disp(['Estimation took ' num2str(toc./60) ' minutes.']);
disp(' ');


if exitflag == 1
  disp('Convergence achieved.');
elseif exitflag == 2
  disp('Convergence achieved by criterion based on change in parameters.');
  if size(PARAMTOL,1)>0
     disp(['Parameters changed less than PARAMTOL= ' num2str(PARAMTOL)]);
  else
     disp('Parameters changed less than PARAMTOL=0.000001, set by default.');
  end
  disp('You might want to check whether this is actually convergence.');
  disp('The gradient vector is');
  disp(grad')
elseif exitflag == 3
  disp('Convergence achieved by criterion based on change in log-likelihood value.');
  if size(PARAMTOL,1)>0
     disp(['Log-likelihood value changed less than LLTOL= ' num2str(LLTOL)]);
  else
     disp('Log-likelihood changed less than LLTOL=0.000001, set by default.');
  end
     disp('You might want to check whether this is actually convergence.');
     disp('The gradient vector is');
     grad;
else
    disp('Convergence not achieved.');
    disp('The current value of the parameters and hessian');
    disp('can be accesses as variables paramhat and hessian.');
    disp('Results are not printed because no convergence.');
    return
end

disp(['Value of the log-likelihood function at convergence: ' num2str(-fval)]);

try
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculate standard errors of parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp(' ');
disp('Taking inverse of hessian for standard errors.');
disp(' ');
ihess=inv(hessian);
stderr=sqrt(diag(ihess));
disp(['The value of grad*inv(hessian)*grad is: ' num2str(grad'*ihess*grad)]);

% Recover the parameters in Matrix format, easier to read and manipulate
M_param=Vect2Mat(paramhat,Posit);
M_se=Vect2Mat(stderr,Posit);


%Segment parameters and account for unestimated zero mean in distribution 5
if NF>0
  fhat=M_param(:,1:NF);
  fsd=M_se(:,1:NF);
end

if NF2>0
  fhat2=M_param(:,(NF+1):(NF+NF2));
  fsd2=M_se(:,(NF+1):(NF+NF2));
end

if NV>0
     % mean of random coefficients 
     bhat=M_param(:,(NF+NF2)+1);
     bsd=M_se(:,(NF+NF2)+1);
     % Choleski factor for variance-covariance matrix
     try
     Ltemp=M_param(:,(NF+NF2)+1+(1:NV));
     % Compute variance-covariance matrix from Choleski factor
     what=diag(Ltemp*Ltemp');
     wsd=diag(M_se(:,(NF+NF2)+1+(1:NV)));
     catch
     Ltemp=zeros(size(bhat,1),size(bhat,1));
          what=zeros(size(bhat,1),size(bhat,1));
               wsd=zeros(size(bhat,1),size(bhat,1));    
     end
end

if any(Fix_TrembNoi)
TNhat=M_param(1,end);
TNsd=M_se(1,end);
else
TNhat=[];
TNsd=[];
    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Display results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('RESULTS');
if NF>0
    tempfhat=fhat(isnan(F)==0)';
    tempfsd=fsd(isnan(F)==0)';

    disp('FIXED COEFFICIENTS');
disp(' ');
disp('                                            F      ');
disp('                                   ------------------ ');
disp('                                    Est         SE ');
for r=1:length(NAMESF);
    fprintf('%-30s %10.4f %10.4f\n', NAMESF{1,r}, [tempfhat(1,r) tempfsd(:,r)]);
end
disp(' ');
end

if NF2>0
    tempfhat2=fhat2(isnan(F2)==0)';
    tempfsd2=fsd2(isnan(F2)==0)';

    disp('FIXED COEFFICIENTS, VARIANCE COVIARANCE');
disp(' ');
disp('                                            F2      ');
disp('                                   ------------------ ');
disp('                                    Est         SE ');
for r=1:length(NAMESF);
    fprintf('%-30s %10.4f %10.4f\n', NAMESF{1,r}, [tempfhat2(1,r) tempfsd2(:,r)]);
end
disp(' ');
end


if NV>0;
disp('RANDOM COEFFICIENTS');

disp('                                          B                      W ');
disp('                                  ------------------   -----------------------');
disp('                                     Est       SE          Est         SE');
for r=1:length(NAMES);
    fprintf('%-30s %10.4f %10.4f %10.4f %10.4f\n', NAMES{r,1}, [bhat(r,1) bsd(r,1) what(r,1) wsd(r,1)]);
end
if any(Fix_TrembNoi)
     fprintf('%-30s %10.4f %10.4f ', Fix_TrembNoi, [TNhat(end,1) TNsd(end,1)]);
end
end
disp(' ')


disp(' ');
disp('You can access the vector of estimated parameters as variable paramhat,');
disp('You can access the vector of estimated mean parameters as variable bhat,');
disp('You can access the matrix of estimated variance-covariance parameters as variable what,');
disp('You can access the vector of estimated fixed coefficients, if any, as variable fhat,');
disp('You can access the vector of estimated fixed coefficients on variance, if any, as variable fhat2');

disp('the gradient of the negative of the log-likelihood function as variable grad,');
disp('the hessian of the negative of the log-likelihood function as variable hessian,');
disp('and the inverse of the hessian as variable ihess.');
disp('The hessian is calculated by the BFGS updating procedure.');
disp( ' ')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Displayed transformed values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

xhat=bhat;
ghat=bhat;
% Delta method for mean only, computation remain to be done for variances.

       % 2. lognormal: coefficient is exp(beta) where beta~N(b,w) with b and w estimated
                xhat(IDV(:,1) == 2,1)=exp(bhat(IDV(:,1) == 2,:));
                ghat(IDV(:,1) == 2,1)=exp(bhat(IDV(:,1) == 2,:));
               
                    
        % 3. truncated normal, with the share below zero massed at zero: max(0,beta) where  beta~N(b,w) with b and w estimated.
    
        % 4. S_B: exp(beta)/(1+exp(beta))  where beta~N(b,w) with b and w estimated.
                xhat(IDV(:,1) == 4,:)=exp(bhat(IDV(:,1) == 4,:))./(1+exp(bhat(IDV(:,1) == 4,:)));
                ghat(IDV(:,1) == 4,:)=exp(bhat(IDV(:,1) == 4,:))./(1+exp(bhat(IDV(:,1) == 4,:))).^2;

         
if any(Fix_TrembNoi)
    if strcmp(Fix_TrembNoi,'Tremble')         
        yhat=exp(TNhat)./(1+exp(TNhat));
        gyhat=exp(TNhat)./(1+exp(TNhat)).^2;  
    elseif strcmp(Fix_TrembNoi,'Noise')  
        yhat=exp(TNhat);
        gyhat=exp(TNhat);
    elseif strcmp(Fix_TrembNoi,'Noise_losses')  % Starting value of loss-specific noise
        yhat=exp(bhat(end,1)+TNhat);
        gyhat=exp(bhat(end,1)+TNhat);
    end
    else
        yhat=[];
        gyhat=[];    
end                
  
if NV>0;
disp('RANDOM COEFFICIENTS, TRANSFORMED VALUES of MEANS, SE computed by Delta Method');

disp(' ');
disp('                                          B                   Distribution');
disp('                                  ------------------    ------------------------------ ');
disp('                                     Est       SE         MEDIAN     MEAN  ST. DEV. ');
for r=1:length(NAMES);
    fprintf('%-30s %10.4f %10.4f %10.4f %10.4f %10.4f\n', NAMES{r,1}, [xhat(r,1) bsd(r,1).*ghat(r,1) xhat(r,1) exp(bhat(r,1)+what(r,1)/2) sqrt((exp(what(r,1))-1).*exp(2.*bhat(r,1)+what(r,1)))]);
end
if any(Fix_TrembNoi)
     fprintf('%-30s %10.4f %10.4f ', Fix_TrembNoi, [yhat(end,1) TNsd.*gyhat(end,1)]);
end
end
disp(' ')

save(save_name);
save('LastEstim');
end
