function [CR]=Parfor_ValueFunction(Param,Gains, Losses ,Mixed)

% Function [CR]=Parfor_ValueFunction(Param,Gains, Losses ,Mixed)
% CR: CE of the riksy option
%
% Old version calls [VR VS CR CS]=ValueFunction_2(Param,Gains, Losses ,Mixed ,Type)
% For a variety of functionals described by Type
% Value function [VR VS CR CS]=Value(Param)
% VR: value of the risky option
% VS: value of the safe option
% CR: CE of the riksy option
% CS: CE of the safe option




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%               YAARI (Sign-dependent)           %%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%% GAINS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Gains, UTILITY
Uhigh_Gains=bsxfun(@times,Gains(:,3),1+0*Param(:,1)');

Ulow_Gains=bsxfun(@times,Gains(:,4),1+0*Param(:,1)');

% Gains, weighting
AL_p_Gains=bsxfun(@power,-log(Gains(:,2)),Param(:,2)');
BE_p_Gains=bsxfun(@times,-AL_p_Gains,Param(:,3)');
W_Gains=exp(BE_p_Gains);

% Gains, Values
VA_Gains=W_Gains.*(Uhigh_Gains-Ulow_Gains)+Ulow_Gains;

% Gains, Certainty Equivalents
CA_Gains=VA_Gains;


%%%%%%%%%%%% LOSSES %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Losses, UTILITY
Uhigh_Losses=bsxfun(@times,Losses(:,3),1+0*Param(:,1)');

Ulow_Losses=bsxfun(@times,Losses(:,4),1+0*Param(:,1)');

% Losses, weighting
AL_p_Losses=bsxfun(@power,-log(Losses(:,2)),Param(:,4)');
BE_p_Losses=bsxfun(@times,-AL_p_Losses,Param(:,5)');
W_Losses=exp(BE_p_Losses);

% Losses, Values
VA_Losses=W_Losses.*(Uhigh_Losses-Ulow_Losses)+Ulow_Losses;

% Losses, Certainty Equivalents

CA_Losses=VA_Losses;


%%%%%%%%%%%% MIXED %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% MIXED, UTILITY
Uhigh_Mixed=bsxfun(@times,Mixed(:,3),1+0*Param(:,1)');


% Mixed, weighting
AL_p_Mixed1=bsxfun(@power,-log(Mixed(:,2)),Param(:,2)');
BE_p_Mixed1=bsxfun(@times,-AL_p_Mixed1,Param(:,3)');
W_Mixed1=exp(BE_p_Mixed1);

AL_p_Mixed2=bsxfun(@power,-log(1-Mixed(:,2)),Param(:,4)');
BE_p_Mixed2=bsxfun(@times,-AL_p_Mixed2,Param(:,5)');
W_Mixed2=exp(BE_p_Mixed2);


% Mixed, Values
VA_Mixed=-W_Mixed1.*Uhigh_Mixed./(W_Mixed2.*Param(:,1)');

% Mixed, Certainty Equivalents
CA_Mixed=VA_Mixed;

% REGROUP GAINS LOSSES MIXED
CR=[CA_Gains;CA_Losses;CA_Mixed];

