function [CR CS]=Parfor_ValueFunction_PT(Param,Gains, Losses ,Mixed)

% Function [CR]=Parfor_ValueFunction(Param,Gains, Losses ,Mixed)
% CR: CE of the riksy option
%
% Old version calls [VR VS CR CS]=ValueFunction_2(Param,Gains, Losses ,Mixed ,Type)
% For a variety of functionals described by Type
% Value function [VR VS CR CS]=Value(Param)
% VR: value of the risky option
% VS: value of the safe option
% CR: CE of the riksy option
% CS: CE of the safe option

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%               PROSPECT THEORY                  %%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%% GAINS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Gains, UTILITY
MU_Xhigh_Gains=bsxfun(@times,Gains(:,3),Param(:,1)');
Uhigh_Gains=bsxfun(@rdivide,1-exp(-MU_Xhigh_Gains),Param(:,1)');

MU_Xlow_Gains=bsxfun(@times,Gains(:,4),Param(:,1)');
Ulow_Gains=bsxfun(@rdivide,1-exp(-MU_Xlow_Gains),Param(:,1)');

MU_Xsure_Gains=bsxfun(@times,Gains(:,5),Param(:,1)');
Usure_Gains=bsxfun(@rdivide,1-exp(-MU_Xsure_Gains),Param(:,1)');


% Gains, weighting
AL_p_Gains=bsxfun(@power,-log(Gains(:,2)),Param(:,4)');
BE_p_Gains=bsxfun(@times,-AL_p_Gains,Param(:,5)');
W_Gains=exp(BE_p_Gains);


% Gains, Values
VA_Gains=W_Gains.*(Uhigh_Gains-Ulow_Gains)+Ulow_Gains;
VB_Gains=Usure_Gains;

% Gains, Certainty Equivalents
temp=bsxfun(@times,VA_Gains,Param(:,1)');

CA_Gains=bsxfun(@rdivide,-log(1-temp),Param(:,1)');

CB_Gains=bsxfun(@times,(Gains(:,5)),1+0.*Param(:,1)');



%%%%%%%%%%%% LOSSES %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Losses, UTILITY
MU_Xhigh_Losses=bsxfun(@times,-Losses(:,3),Param(:,2)');
Uhigh_Losses=bsxfun(@rdivide,1-exp(-MU_Xhigh_Losses),-Param(:,2)');

MU_Xlow_Losses=bsxfun(@times,-Losses(:,4),Param(:,2)');
Ulow_Losses=bsxfun(@rdivide,1-exp(-MU_Xlow_Losses),-Param(:,2)');

MU_Xsure_Losses=bsxfun(@times,-Losses(:,5),Param(:,2)');
Usure_Losses=bsxfun(@rdivide,1-exp(-MU_Xsure_Losses),-Param(:,2)');


% Losses, weighting
AL_p_Losses=bsxfun(@power,-log(Losses(:,2)),Param(:,6)');
BE_p_Losses=bsxfun(@times,-AL_p_Losses,Param(:,7)');
W_Losses=exp(BE_p_Losses);

% Losses, Values
VA_Losses=W_Losses.*(Uhigh_Losses-Ulow_Losses)+Ulow_Losses;
VB_Losses=Usure_Losses;

% Losses, Certainty Equivalents
temp=bsxfun(@times,VA_Losses,-Param(:,2)');

CA_Losses=bsxfun(@rdivide,-log(1-temp),-Param(:,2)');

CB_Losses=bsxfun(@times,(Losses(:,5)),1+0.*Param(:,2)');



%%%%%%%%%%%% MIXED %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% MIXED, UTILITY
MU_Xhigh_Mixed=bsxfun(@times,Mixed(:,3),Param(:,1)');
Uhigh_Mixed=bsxfun(@rdivide,1-exp(-MU_Xhigh_Mixed),Param(:,1)');

LA=bsxfun(@times,Mixed(:,4)*0+1,Param(:,3)');

MU_Xsure_Mixed=bsxfun(@times,Mixed(:,5),Param(:,1)');
Usure_Mixed=bsxfun(@rdivide,1-exp(-MU_Xsure_Mixed),Param(:,1)');


% Mixed, weighting
AL_p_Mixed1=bsxfun(@power,-log(Mixed(:,2)),Param(:,4)');
BE_p_Mixed1=bsxfun(@times,-AL_p_Mixed1,Param(:,5)');
W_Mixed1=exp(BE_p_Mixed1);

AL_p_Mixed2=bsxfun(@power,-log(1-Mixed(:,2)),Param(:,6)');
BE_p_Mixed2=bsxfun(@times,-AL_p_Mixed2,Param(:,7)');
W_Mixed2=exp(BE_p_Mixed2);


% Mixed, Values
VA_Mixed=-W_Mixed1.*Uhigh_Mixed./(W_Mixed2.*LA);
VB_Mixed=Usure_Mixed;

% Mixed, Certainty Equivalents
% Check wether VA_Mixed is a gain or a loss
temp2=bsxfun(@times,double(VA_Mixed.*(VA_Mixed<=0)),-Param(:,2)');


CA_Mixed=bsxfun(@rdivide,-log(1-temp2),-Param(:,2)');
CA_Mixed(imag(CA_Mixed)~=0)=-100;

CB_Mixed=bsxfun(@times,(Mixed(:,5)),1+0.*Param(:,2)');


% REGROUP GAINS LOSSES MIXED

value_optionA=[VA_Gains;VA_Losses;VA_Mixed];
value_optionB=[VB_Gains;VB_Losses;VB_Mixed];

CE_optionA=[CA_Gains;CA_Losses;CA_Mixed];
CE_optionB=[CB_Gains;CB_Losses;CB_Mixed];


% REGROUP GAINS LOSSES MIXED
CR=[CA_Gains;CA_Losses;CA_Mixed];
CS=[CB_Gains;CB_Losses;CB_Mixed];

