function PnC=llgrad2(f,b,L,Var_TN,Choice_Gains, Choice_Losses, Choice_Mixed ,COVARIATES,draws) 

% Calculate log likelihood for a sequence of choices among alternatives for each person
%    with multiple choice situations for each person and multiple people,
% Inspired by the script Written by Kenneth Train, first version on July 14, 2006..


global Gains Losses Mixed
global NV NF IDV IDF


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Arrays
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Size of Arrays
Nperson=size(draws,1);
Nparam=size(b,1);
Ndraws=size(draws,2);

% Flip dimensions of Fixed effects (parameter as columns, covariates as rows)
F=f';


% Replaced Nan by zeros
F(isnan(F))=0;
L(isnan(L))=0;

% Preallocate Arrays
%unobs=zeros(Ndraws,Nparam);
%obsi=zeros(Ndraws,Nparam,size(draws,3));
%parameters=zeros(Ndraws,Nparam);

PnC=nan(Nperson,Ndraws);

temp_NV=NV;
temp_NF=NF;

temp_IDF=IDF;
temp_IDV=IDV;

% Create sliced variables to avoid problem in parrallel computations




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Loop over individuals
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% Use a for loop for simple computations, debug and for use of global variables
% Use a parfor loop for parrallel computing
% Code is parallelized

%Use the same set of covariates for all parameters
% This can be generalized using previous version of the program

    % Observed heterogeneity in parameters
    
     all_obs=zeros(Nperson,NV);
   
    if temp_NF>0
        temp_COV=COVARIATES(:,temp_IDF(:,2)==1);

        if any(temp_COV)
            all_obs=temp_COV*F;
                end
    end
  
 % parfor   
parfor i=1:Nperson
   
   
    % preallocate observed heterogeneity
    obs=zeros(Ndraws,temp_NV);
    
    obs=repmat(all_obs(i,:),Ndraws,1);

  % Replicate individual i choice for each sample of parameters
    temp=[Choice_Gains(i,:)'; Choice_Losses(i,:)' ;Choice_Mixed(i,:)'];
    CER=repmat(temp,1,size(draws,2));
    
     % Unobserved heterogeneity in parameters, 1. normal: N(b,w) where mean b and variance covariance w are estimated.
    unobs=MVR2(b,L,squeeze(draws(i,:,:)));
    
     % no Observed heterogeneity in parameters
    if temp_NF==0
        obs=0*unobs;
    end
     
    % Compute parameters values
try
    param=unobs+obs;
catch
    disp('Problem in concatenation of observables/unobservables')
end
 % Transform parameter values: 
        % 2. lognormal: coefficient is exp(beta) where beta~N(b,w) with b and w estimated
                param(:,temp_IDV(:,1) == 2,:)=exp(param(:,temp_IDV(:,1) == 2,:));
    
        % 3. truncated normal, with the share below zero massed at zero: max(0,beta) where  beta~N(b,w) with b and w estimated.
                param(:,temp_IDV(:,1) == 3,:)=param(:,temp_IDV(:,1) == 3,:).*(param(:,temp_IDV(:,1) == 3,:)>0);
    
        % 4. S_B: exp(beta)/(1+exp(beta))  where beta~N(b,w) with b and w estimated.
                param(:,temp_IDV(:,1) == 4,:)=exp(param(:,temp_IDV(:,1) == 4,:))./(1+exp(param(:,temp_IDV(:,1) == 4,:)));
                
 
                Noise=[param(:,Nparam) exp(log(param(:,Nparam))+Var_TN)];
         
  
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   % 1. Evaluate conditional probabilities for each element of the sequence
  
[CR]=Parfor_ValueFunction(param,Gains, Losses ,Mixed);

    % Compute absolute difference between the outcome
    Range_Gains=abs(Gains(:,3)-Gains(:,4));
    Range_Losses=abs(Losses(:,3)-Losses(:,4));
    %Range_Mixed=Mixed(:,3)*0+max(abs(Mixed(:,3)-Mixed(:,4)))./2;
    Range_Mixed=abs(0-Mixed(:,4));

%     if Type==3     % Expected utility restriction to gains
%         Range=Range_Gains;
%     else            % No restriction
%         Range=[Range_Gains ;Range_Losses; Range_Mixed];
%     end
%     
% if Heteroskedastic==0
%     Range=Range*0+1;
% end

% Redefine noise value with absolute difference
    Noise_Gains=bsxfun(@times,Range_Gains,Noise(:,1)')'; 
    Noise_Losses=bsxfun(@times,Range_Losses,Noise(:,2)')'; 
    Noise_Mixed=bsxfun(@times,Range_Mixed,Noise(:,2)')'; 
    %Noise_Mixed=bsxfun(@times,Range_Mixed,(Noise(:,1)'+Noise(:,2)')./2)'; 
    Noise_Total=[Noise_Gains,Noise_Losses,Noise_Mixed];


% Compute pdf
try
Prnt=normpdf(CER-CR,0,Noise_Total');
catch
Prnt=CR*0+realmin;
end

% Avoid computional pbs in zero
Prnt(Prnt==0)=realmin;

% Deal with NaN
Prnt(isnan(Prnt))=1;
    
    
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % 2. EVALUATE inconditional probabilities for the whole sequence
    PnC(i,:)=prod(Prnt);
  
    
end

