% Calculates log-likelihood function 
% Inspired by the code written by Kenneth Train, July 27, 2006, revised July 31, 2006
% This code is input to Matlab's funcmin command
%
% Input param is a column vector of parameters, dimension (NF+NF2+NV+NV)x1
%     containing the fixed coefficients, the first parameters of the random
%     coefficients, and then the second parameters of the random coefficients
% Output ll is the scalar value of the negative of the simulated log-likelihood 
%     at the input parameters

function [ll] =loglik(param_Vector)

% param     : parameters dimension (NF+NV+NV)x1
% NV        : number of random coefficients
% NF        : number of fixed coefficients
% IDV       : contains one row for each random coefficient and two columns.
% COV      : Covariable matrix
% draws     : Halton draws

%global Gains Losses Mixed Type
%global Probit
global Choice_Gains Choice_Losses Choice_Mixed COVARIATES
global NV NF IDV IDF NF2
global Posit
global draws
%global Heteroskedastic Var_TrembNoi Fix_TrembNoi Sign_TrembNoi
%global Final


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Recover Paramters in Matrix Form
param=Vect2Mat(param_Vector,Posit);

% Remark: turn a vector to a upper triangular matrix
% a = [1 2 3 4 5 6 7 8 9 10];
% b = triu(ones(5),1);
% b(~~b)=a
%
% Interpretation:
% ~b returns a logical array the same size as b with true
% values (1) where b is zero and false values (0) where b is
% nonzero.
% 
% ~(~b) then gives another logical array the same size as (~b)
% which gives false values (0) where (~b) is true and true
% values (1) where (~b) is false.
% 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Recover Fixed vs. Random parameters
if NF>0
  f=param(:,1:NF);  % f:    value of fixed parameters 
else
  f=[];
end

if NF2>0
  f2=param(:,(NF+1):(NF+NF2));  % f:    value of fixed parameters 
else
  f2=[];
end


if NV>0
     b=param(:,(NF+NF2)+1);               % mean
     try
     L=param(:,((NF+NF2)+2):((NF+NF2)+NV)+1);   % sd
     catch
         L=zeros(size(b,1),size(b,1));
         disp('Problem with L matrix in loglik');
     end
else                            % no random parameters
  b=[];
  L=[];
end

Var_TN=param(1,size(param,2));



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Arrays
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Size of Arrays
Nperson=size(draws,3);
Ndraws=size(draws,1);

% Preallocate Arrays to increase performance
Indi_like=nan(Nperson);
Pnc=nan(Nperson,Ndraws);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% External call: likelihood function
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Call likelihood
PnC=llgrad2(f,b,L,Var_TN,Choice_Gains, Choice_Losses, Choice_Mixed ,COVARIATES,draws);

% Avoid pbs with zero values
PnC(PnC<realmin)=realmin;

% Average values to get individual likelihood
Indi_like=mean(PnC,2);

% Sum over individuals to get log-likelihood
ll=-sum(log(Indi_like));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    
