***********************
***import data
***********************
*NOTE:
* this do-file allows the replication of the main results reported in the manuscript
* additional programmes for stability checks is also provided, e.g. the full PT model reported in the Online Appendix
* in case of questions, email fvieider@gmail.com

*set the home directory to where the files have been saved

import delimited data_30countries.csv


*******************************************************************************************************************
***define main program: used for main analysis with piecwise linear utility in the body of the paper
*******************************************************************************************************************

capture program drop Yaari

program define Yaari

args lnf alpha beta gamma delta lambda noise

tempvar probhigh high_amount low_amount equivalent weighting_gains weighting_losses utility_high utility_low utility_prospect ce_calc PTdiff

quietly {
generate double `probhigh' = $ML_y1
generate double `high_amount' = $ML_y2
generate double `low_amount' = $ML_y3
generate double `equivalent' = $ML_y4

generate double `utility_high' = .
replace `utility_high' = (`high_amount') if `high_amount'>=0
replace `utility_high' = -(-`high_amount') if `high_amount'<=0
 
generate double `utility_low' = .
replace `utility_low' = (`low_amount') if `low_amount'>=0
replace `utility_low' = -(-`low_amount') if `low_amount'<=0

generate double `weighting_gains' = exp(-`beta'*(-ln(`probhigh'))^`alpha')
generate double `weighting_losses' = exp(-`delta'*(-ln(`probhigh'))^`gamma')

generate double `utility_prospect' = .
replace `utility_prospect' = (`weighting_gains'*`utility_high') + ((1-`weighting_gains')*`utility_low') if `high_amount'>0 & `low_amount'>=0 & equiv_nr!=44
replace `utility_prospect' = (`weighting_losses'*`utility_high') + ((1-`weighting_losses')*`utility_low') if `high_amount'<0 & `low_amount'<=0
replace `utility_prospect' = -(`weighting_gains'*`utility_high')/(`lambda'*(`weighting_losses')) if equiv_nr==44

generate double `ce_calc' = .
replace `ce_calc' = `utility_prospect' if `high_amount'>0 & `low_amount'>=0 & equiv_nr!=44
replace `ce_calc' = -(-`utility_prospect') if `high_amount'<0 & `low_amount'<=0
replace `ce_calc' = -(-`utility_prospect') if equiv_nr==44

generate double `PTdiff' = (`ce_calc'-`equivalent')
 
replace `lnf' = ln(normalden(`PTdiff',0,(`noise'*abs(`high_amount'-`low_amount'))))
 
}
end


***************************************************************************************************
***Full PT model, expo utility function: used for stabiility analysis in online appendix
***************************************************************************************************


capture program drop PT_expo

program define PT_expo

args lnf mu ni lambda alpha beta gamma delta noise

tempvar probhigh high_amount low_amount equivalent weighting_gains weighting_losses utility_high utility_low utility_prospect ce_calc PTdiff

quietly {
generate double `probhigh' = $ML_y1
generate double `high_amount' = $ML_y2
generate double `low_amount' = $ML_y3
generate double `equivalent' = $ML_y4

generate double `utility_high' = .
replace `utility_high' = (1-exp(-`mu'*`high_amount'))/`mu' if `high_amount'>=0
replace `utility_high' = -(1-exp(-`ni'*-`high_amount'))/`ni' if `high_amount'<0
 
generate double `utility_low' = .
replace `utility_low' = (1-exp(-`mu'*`low_amount'))/`mu' if `low_amount'>=0
replace `utility_low' = -(1-exp(-`ni'*-`low_amount'))/`ni' if `low_amount'<0

generate double `weighting_gains' = exp(-`beta'*(-ln(`probhigh'))^`alpha')
generate double `weighting_losses' = exp(-`delta'*(-ln(`probhigh'))^`gamma')

generate double `utility_prospect' = .
replace `utility_prospect' = (`weighting_gains'*`utility_high') + ((1-`weighting_gains')*`utility_low') if `high_amount'>0 & `low_amount'>=0 & equiv_nr!=44
replace `utility_prospect' = (`weighting_losses'*`utility_high') + ((1-`weighting_losses')*`utility_low') if `high_amount'<0 & `low_amount'<=0
replace `utility_prospect' = -(`weighting_gains'*`utility_high')/(`lambda'*`weighting_losses') if equiv_nr==44

generate double `ce_calc' = .
replace `ce_calc' = ln(1-`utility_prospect'*`mu')/(-`mu') if `high_amount'>0 & `low_amount'>=0 & equiv_nr!=44
replace `ce_calc' = ln(1+`utility_prospect'*`ni')/`ni' if `high_amount'<0 & `low_amount'<=0
replace `ce_calc' = ln(1+`utility_prospect'*`ni')/`ni' if equiv_nr==44

generate double `PTdiff' = (`ce_calc'-`equivalent')
 
replace `lnf' = ln(normalden(`PTdiff',0,(`noise'*abs(`high_amount'-`low_amount'))))
 
}
end



**********************************************************************
***graphs illustrating weighting function properties
**********************************************************************


tw (function y=exp(-1*((-ln(x))^0.9)), range(0 1) lcolor(dkgreen) lwidth(thick))/*
*/ (function y=exp(-1*((-ln(x))^0.7)), range(0 1) lcolor(yellow) lwidth(thick))/*
*/ (function y=exp(-1*((-ln(x))^0.5)), range(0 1) lcolor(red) lpattern(-..-..) lwidth(thick))/*
*/ (function y=exp(-1*((-ln(x))^0.3)), range(0 1) lcolor(green) lpattern(-) lwidth(thick))/*
*/ (function y=exp(-1*((-ln(x))^0.1)), range(0 1) lcolor(blue) lwidth(thick))/*
*/ (function y=x, range(0 1) lcolor(black) lpattern(-...-...)),/*
*/ legend(label(1 "alpha = 0.9") label(2 "alpha = 0.7") label(3 "alpha = 0.5") label(4 "alpha = 0.3") label(5 "alpha = 0.1") label(6 "linear") ring (0) rows(4) position(11) size(small)) xtitle("p") ytitle("w(p)") xlab(0(0.1)1) ylab(0(0.1)1) yscale(alt)



tw (function y=exp(-0.6*((-ln(x))^0.65)), range(0 1) lcolor(dkgreen) lwidth(thick))/*
*/ (function y=exp(-0.8*((-ln(x))^0.65)), range(0 1) lcolor(yellow) lwidth(thick))/*
*/ (function y=exp(-1*((-ln(x))^0.65)), range(0 1) lcolor(red) lpattern(-..-..) lwidth(thick))/*
*/ (function y=exp(-1.2*((-ln(x))^0.65)), range(0 1) lcolor(green) lpattern(-) lwidth(thick))/*
*/ (function y=exp(-1.4*((-ln(x))^0.65)), range(0 1) lcolor(blue) lwidth(thick))/*
*/ (function y=x, range(0 1) lcolor(black) lpattern(-...-...)),/*
*/ legend(label(1 "beta = 0.6") label(2 "beta = 0.8") label(3 "beta = 1") label(4 "beta = 1.2") label(5 "beta = 1.4") label(6 "linear") ring (0) rows(4) position(11) size(small)) xtitle("p") ytitle("w(p)") xlab(0(0.1)1) ylab(0(0.1)1) yscale(alt)





**********************************************************************
***model 0: global estimates
**********************************************************************


ml model lf Yaari (alpha: probability high low equivalent = ) (beta: = ) (gamma:  = ) (delta:  = ) (lambda:  = ) (noise: = loss), technique(bfgs) maximize init(alpha:_cons=.8 beta:_cons=1  gamma:_cons=.8 delta:_cons=1 lambda:_cons=1.5 noise:_cons=0.2) iterate(5000)
ml display


**********************************************************************
***model 0: graph global parameters (gains and losses in one graph)
**********************************************************************


**Dual function:
tw (function y=exp(-0.908*((-ln(x))^0.602)), range(0 1) lcolor(dkgreen) lwidth(thick))/*
*/ (function y=exp(-0.941*((-ln(x))^0.641)), range(0 1) lcolor(blue) lpattern(-) lwidth(thick))/*
*/ (function y=x, range(0 1) lcolor(black) lpattern(-...-...)),/*
*/ legend(label(1 "gains") label(2 "losses") label(3 "linear") ring (0) rows(4) position(11) size(small)) xtitle("p") ytitle("w(p)") xlab(0(0.1)1) ylab(0(0.1)1) yscale(alt)



**********************************************************************
***model 1: country fixed effects
**********************************************************************
***NOTE: loss=1 for losses and mixed!

local countries "Australia Belgium Brazil Cambodia Chile China Colombia Costarica Czech Ethiopia France Germany Guatemala India Japan Kyrgyzstan Malaysia Nicaragua Nigeria Peru Poland Russia Saudi Southafrica Spain Thailand Tunisia UK Vietnam female"
ml model lf Yaari (alpha: probability high low equivalent = `countries') (beta: = `countries') (gamma:  = `countries') (delta:  = `countries') (lambda:  = `countries') (noise: = `countries' loss), technique(bfgs) cluster(subject_global) maximize init(alpha:_cons=.8 beta:_cons=1  gamma:_cons=.8 delta:_cons=1 lambda:_cons=1.5 noise:_cons=0.2) iterate(5000)
ml display


*******************************************
***create graphs for probability weighting
*******************************************
**gains:

tw (function y=exp(-1.05*((-ln(x))^0.79)), range(0 1) lcolor(dkgreen) lwidth(thick))/*
*/ (function y=exp(-0.96*((-ln(x))^0.73)), range(0 1) lcolor(yellow) lwidth(thick))/*
*/ (function y=exp(-0.69*((-ln(x))^0.59)), range(0 1) lcolor(red) lpattern(-..-..) lwidth(thick))/*
*/ (function y=exp(-0.83*((-ln(x))^0.67)), range(0 1) lcolor(green) lpattern(-) lwidth(thick))/*
*/ (function y=exp(-0.74*((-ln(x))^0.63)), range(0 1) lcolor(blue) lwidth(thick))/*
*/ (function y=exp(-0.87*((-ln(x))^0.72)), range(0 1) lcolor(orange) lpattern(-) lwidth(thick))/*
*/ (function y=x, range(0 1) lcolor(black) lpattern(-...-...)),/*
*/ legend(label(1 "USA") label(2 "China") label(3 "Nicaragua") label(4 "Vietnam") label(5 "Ethiopia") label(6 "Malaysia") label(7 "linear") ring (0) rows(4) position(4)) xtitle("p") ytitle("w(p)") xlab(0(0.1)1) ylab(0(0.1)1) yscale(alt)
graph export "/Users/nando/Dropbox/World Wide Prospect Theory/All_over_the_map/graph_yaari_gains.eps", as(eps) preview(off) replace

**losses:
**using different countries:
tw (function y=exp(-0.95*((-ln(x))^0.87)), range(0 1) lcolor(dkgreen) lwidth(thick))/*
*/ (function y=exp(-0.90*((-ln(x))^0.77)), range(0 1) lcolor(yellow) lwidth(thick))/*
*/ (function y=exp(-0.99*((-ln(x))^0.53)), range(0 1) lcolor(red) lpattern(-..-..) lwidth(thick))/*
*/ (function y=exp(-1.13*((-ln(x))^1.01)), range(0 1) lcolor(blue) lwidth(thick))/*
*/ (function y=exp(-1.16*((-ln(x))^0.45)), range(0 1) lcolor(green) lpattern(-) lwidth(thick))/*
*/ (function y=x, range(0 1) lcolor(black) lpattern(-...-...)),/*
*/ legend(label(1 "USA") label(2 "China") label(3 "Ethiopa") label(4 "Guatemala") label(5 "Cambodia") label(6 "linear") ring (0) rows(3) position(4)) xtitle("p") ytitle("w(p)") xlab(0(0.1)1) ylab(0(0.1)1) yscale(alt)
graph export "/Users/nando/Dropbox/World Wide Prospect Theory/All_over_the_map/graph_yaari_losses.eps", as(eps) preview(off) replace

 

******************************************
***estimate parameter values at country level
******************************************

gen alpha=.
gen beta=.
gen gamma=.
gen delta=.
gen lambda=.
gen sigma=.

forvalues i=1(1)30 {
display "country `i'"
capture ml model lf Yaari (alpha: probability high low equivalent = ) (beta: = ) (gamma:  = ) (delta:  = ) (lambda:  = ) (noise: = loss) if country==`i', technique(bfgs) cluster(subject_global) maximize init(alpha:_cons=.8 beta:_cons=1  gamma:_cons=.8 delta:_cons=1 lambda:_cons=1.5 noise:_cons=0.2) iterate(5000)
ml display

matrix yaari_results = e(b)
scalar scalar_alpha = el(yaari_results,1,1)
scalar scalar_beta = el(yaari_results,1,2)
scalar scalar_gamma = el(yaari_results,1,3)
scalar scalar_delta = el(yaari_results,1,4)
scalar scalar_lambda = el(yaari_results,1,5)
scalar scalar_sigma = el(yaari_results,1,6)
replace alpha = scalar_alpha if country == `i'
replace beta = scalar_beta if country == `i'
replace gamma = scalar_gamma if country == `i'
replace delta = scalar_delta if country == `i'
replace lambda = scalar_lambda if country == `i'
replace sigma = scalar_sigma if country == `i'
estimates store yaari
}



******************************************
***Base graphs on parametrs from country regression
******************************************

import excel "/Users/nando/Dropbox/World Wide Prospect Theory/All_over_the_map/country_effects_table1.xlsx", sheet("Sheet1") firstrow

destring alpha*, replace
destring beta*, replace
destring gamma*, replace
destring delta*, replace
destring lambda*, replace
destring noise*, replace

replace alpha=alpha_cons+alpha
replace beta=beta_cons+beta
replace gamma=gamma_cons+gamma
replace delta=delta_cons+delta
replace lambda=lambda_cons+lambda
replace noise=noise_cons+noise

drop *_cons
sort country


******************************************
***scatter plot weighting function gains
******************************************

gen pos1=12
replace pos1=6 if country_name=="Cambodia"
replace pos1=6 if country_name=="Australia"
replace pos1=9 if country_name=="Germany"
replace pos1=6 if country_name=="Costa Rica"
replace pos1=6 if country_name=="Malaysia"
replace pos1=5 if country_name=="South Africa"
replace pos1=11 if country_name=="Guatemala"
replace pos1=3 if country_name=="Czech Republic"
replace pos1=4 if country_name=="Belgium"
replace pos1=10 if country_name=="Russia"

tw (scatter alpha beta if subject==1, mlabel(country_code) mlabv(pos1) mlabcolor(black) mcolor(blue) msize(medium)  xline(1, lwidth(vthin)) yline(1, lwidth(vthin)))/*
 */ , legend(off) xtitle("beta gains (risk aversion)") ytitle("alpha gains (sensitivity)") xlabel(0.6(0.1)1.1) ylabel(0.3(0.1)1)



******************************************
***scatter plot weighting function losses
******************************************

gen pos2=12
tw (scatter gamma delta if subject==1, mlabel(country_code) mlabv(pos2) mlabcolor(black) mcolor(blue) msize(medium) xline(1, lwidth(vthin)) yline(1, lwidth(vthin)))/*
 */ , legend(off) xtitle("beta losses (risk seeking)") ytitle("alpha losses (sensitivity)") xlabel(0.8(0.1)1.15) ylabel(0.4(0.1)1)




**********************************************************************
***model 2: income effects
**********************************************************************
egen gini_z = std(gini)
gen log_GDP_PPP = ln(gdp_ppp_2011)

local bio "female"
local macro "gdp_diff foreigner gini_z private opec"
ml model lf Yaari (alpha: probability high low equivalent = `macro' `bio') (beta: = `macro' `bio') (gamma:  = `macro' `bio') (delta:  = `macro' `bio') (lambda:  = `macro' `bio') (noise: = `macro' `bio' loss), technique(bfgs) cluster(subject_global) maximize init(alpha:_cons=.8 beta:_cons=1  gamma:_cons=.8 delta:_cons=1 lambda:_cons=1.5 noise:_cons=0.2) iterate(5000)
ml display



**********************************************************************
***model 3: physical characteristics
**********************************************************************

local countries "Australia Belgium Brazil Cambodia Chile China Colombia Costarica Czech Ethiopia France Germany Guatemala India Japan Kyrgyzstan Malaysia Nicaragua Nigeria Peru Poland Russia Saudi Southafrica Spain Thailand Tunisia UK Vietnam"
local bio "female age_z height_norm_sex"

ml model lf Yaari (alpha: probability high low equivalent = `countries' `bio') (beta: = `countries' `bio') (gamma:  = `countries' `bio') (delta:  = `countries' `bio') (lambda:  = `countries' `bio') (noise: = `countries' `bio' loss), technique(bfgs) cluster(subject_global) maximize init(alpha:_cons=.8 beta:_cons=1  gamma:_cons=.8 delta:_cons=1 lambda:_cons=1.5 noise:_cons=0.2) iterate(5000)
ml display

estimates store bio


***export data table
esttab bio using "/Users/nando/Dropbox/World Wide Prospect Theory/All_over_the_map/table_model3_biological.tex", replace scalars(N_clust chi2) noobs sfmt(0 2) b(3) se(3)/*
*/ star(* 0.10 ** 0.05 *** 0.01) unstack varlabels(_cons constant N_clust subjects chi2 Wald) lines/*
*/ title(Country level effects) fragment booktabs


**********************************************************************
***model 4: cultural effects
**********************************************************************



local countries "Australia Belgium Brazil Cambodia Chile China Colombia Costarica Czech Ethiopia France Germany Guatemala India Japan Kyrgyzstan Malaysia Nicaragua Nigeria Peru Poland Russia Saudi Southafrica Spain Thailand Tunisia UK Vietnam"
local bio "female age_z height_z"
local hofstede "individualism uncertainty_avoidance power_distance masculinity"
ml model lf Yaari (alpha: probability high low equivalent = `countries' `bio' `hofstede') (beta: = `countries' `bio' `hofstede') (gamma:  = `countries' `bio' `hofstede') (delta:  = `countries' `bio' `hofstede') (lambda:  = `countries' `bio' `hofstede') (noise: = `countries' `bio' `hofstede' loss), technique(bfgs) cluster(subject_global) maximize init(alpha:_cons=.8 beta:_cons=1  gamma:_cons=.8 delta:_cons=1 lambda:_cons=1.5 noise:_cons=0.2) iterate(5000)
ml display


**********************************************************************
***model 5: religion
**********************************************************************

local countries "Australia Belgium Brazil Cambodia Chile China Colombia Costarica Czech Ethiopia France Germany Guatemala India Japan Kyrgyzstan Malaysia Nicaragua Nigeria Peru Poland Russia Saudi Southafrica Spain Thailand Tunisia UK Vietnam"
local bio "female age_z height_z log_expenses_z"
local religion "atheist catholic orthodox muslim jewish hindu buddist religion_other"
ml model lf Yaari (alpha: probability high low equivalent = `countries' `bio' `religion') (beta: = `countries' `bio' `religion') (gamma:  = `countries' `bio' `religion') (delta:  = `countries' `bio' `religion') (lambda:  = `countries' `bio' `religion') (noise: = `countries' `bio' `religion' loss), technique(bfgs) cluster(subject_global) maximize init(alpha:_cons=.8 beta:_cons=1  gamma:_cons=.8 delta:_cons=1 lambda:_cons=1.5 noise:_cons=0.2) iterate(5000)
ml display



**********************************************************************
***model 6: study major
**********************************************************************

local countries "Australia Belgium Brazil Cambodia Chile China Colombia Costarica Czech Ethiopia France Germany Guatemala India Japan Kyrgyzstan Malaysia Nicaragua Nigeria Peru Poland Russia Saudi Southafrica Spain Thailand Tunisia UK Vietnam"
local bio "female age_z height_z"
local study "gpa_z math natural medicine social humanities arts study_other"
ml model lf Yaari (alpha: probability high low equivalent = `countries' `bio' `study') (beta: = `countries' `bio' `study') (gamma:  = `countries' `bio' `study') (delta:  = `countries' `bio' `study') (lambda:  = `countries' `bio' `study') (noise: = `countries' `bio' `study' loss), technique(bfgs) cluster(subject_global) maximize init(alpha:_cons=.8 beta:_cons=1  gamma:_cons=.8 delta:_cons=1 lambda:_cons=1.5 noise:_cons=0.2) iterate(5000)
ml display



* the model with unobserved heterogeneity was estimated in Matlab
* see included Matlab file




***********************************************************************
***********************************************************************
*****Supplementary materials
***********************************************************************
***********************************************************************

**************************************************************
*** model 0:
**************************************************************

ml model lf PT_expo (mu: probability high low equivalent = ) (ni:  = ) (lambda:  = ) (alpha:  = ) (beta: = ) (gamma:  = ) (delta:  = ) (noise: = loss), technique(bfgs) cluster(subject_global) maximize init(mu:_cons=.05 ni:_cons=.05 lambda:_cons=1.5 alpha:_cons=.8 beta:_cons=.6  gamma:_cons=.8 delta:_cons=.6 noise:_cons=3.2) iterate(5000)
ml display

**************************************************************
*** model 1: country fixed effects, all subjects
**************************************************************

local countries "Australia Belgium Brazil Cambodia Chile China Colombia Costarica Czech Ethiopia France Germany Guatemala India Japan Kyrgyzstan Malaysia Nicaragua Nigeria Peru Poland Russia Saudi Southafrica Spain Thailand Tunisia UK Vietnam female"
ml model lf PT_expo (mu: probability high low equivalent = `countries') (ni:  = `countries') (lambda:  = `countries') (alpha:  = `countries') (beta: = `countries') (gamma:  = `countries') (delta:  = `countries') (noise: = `countries' loss), technique(bfgs) cluster(subject_global) maximize init(mu:_cons=.05 ni:_cons=.05 lambda:_cons=1.5 alpha:_cons=.8 beta:_cons=.6  gamma:_cons=.8 delta:_cons=.6 noise:_cons=3.2) iterate(5000)
ml display


******************************************
***scatter plot weighting function gains
******************************************

***utility

tw (function y=(1-exp(-0.04*x))/0.04, range(0 30) lcolor(dkgreen) lwidth(thick)) || (function y= -1.31*(1-exp(-0.001*abs(x)))/0.001, range(-20 0) lcolor(dkgreen) lwidth(thick))/*
*/ (function y=(1-exp(-0.02*x))/0.02, range(0 30) lcolor(yellow) lwidth(thick)) || (function y= -1.50*(1-exp(0.01*abs(x)))/-0.01, range(-20 0) lcolor(yellow) lwidth(thick))/*
*/ (function y=(1-exp(-0.01*x))/0.01, range(0 30) lcolor(orange) lpattern(-) lwidth(thick)) || (function y= -1.6*(1-exp(-0.01*abs(x)))/0.01, range(-20 0) lcolor(orange) lwidth(thick))/*
*/ (function y=(1-exp(-0.02*x))/0.02, range(0 30) lcolor(blue) lpattern(-) lwidth(thick)) || (function y= -2.23*(1-exp(-0.01*abs(x)))/0.01, range(-20 0) lcolor(blue) lpattern(-) lwidth(thick))/*
*/ (function y=(1-exp(-0.03*x))/0.03, range(0 30) lcolor(red) lpattern(-..-..) lwidth(thick)) || (function y= -2.38*(1-exp(-0.03*abs(x)))/0.03, range(-20 0) lcolor(red) lpattern(-..-..) lwidth(thick))/*
*/, legend(order(1 3 5 7 9) label(1 USA) label(3 China) label(5 Guatemala) label(7 Ethiopia) label(9 Nicaragua) ring (0) rows(5) position(5) bmargin(large))/*
*/ xlab(-20(5)30) ylab(-30(5)30) xtitle("X") ytitle("u(X)") yline(0, lc(black)) xline(0, lc(black))
graph export "/Users/nando/Dropbox/World Wide Prospect Theory/All_over_the_map/graph_utility.eps", as(eps) replace preview(off)


**weighting gains:

tw (function y=exp(-0.834*((-ln(x))^0.858)), range(0 1) lcolor(dkgreen) lwidth(thick))/*
*/ (function y=exp(-0.846*((-ln(x))^0.762)), range(0 1) lcolor(yellow) lwidth(thick))/*
*/ (function y=exp(-0.565*((-ln(x))^0.619)), range(0 1) lcolor(red) lpattern(-..-..) lwidth(thick))/*
*/ (function y=exp(-0.646*((-ln(x))^0.72)), range(0 1) lcolor(green) lpattern(-) lwidth(thick))/*
*/ (function y=exp(-0.675*((-ln(x))^0.64)), range(0 1) lcolor(blue) lwidth(thick))/*
*/ (function y=exp(-0.779*((-ln(x))^0.74)), range(0 1) lcolor(orange) lpattern(-) lwidth(thick))/*
*/ (function y=x, range(0 1) lcolor(black) lpattern(-...-...)),/*
*/ legend(label(1 "USA") label(2 "China") label(3 "Nicaragua") label(4 "Vietnam") label(5 "Ethiopia") label(6 "Malaysia") label(7 "linear") ring (0) rows(4) position(4)) xtitle("p") ytitle("w(p)") xlab(0(0.1)1) ylab(0(0.1)1) yscale(alt)
graph export "/Users/nando/Dropbox/World Wide Prospect Theory/All_over_the_map/graph_weightingPT_examples.eps", as(eps) preview(off)

**weighting losses
tw (function y=exp(-0.939*((-ln(x))^0.871)), range(0 1) lcolor(dkgreen) lwidth(thick))/*
*/ (function y=exp(-0.909*((-ln(x))^0.763)), range(0 1) lcolor(yellow) lwidth(thick))/*
*/ (function y=exp(-0.959*((-ln(x))^0.541)), range(0 1) lcolor(red) lpattern(-..-..) lwidth(thick))/*
*/ (function y=exp(-1.08*((-ln(x))^1.03)), range(0 1) lcolor(blue) lwidth(thick))/*
*/ (function y=exp(-1.128*((-ln(x))^0.451)), range(0 1) lcolor(green) lpattern(-) lwidth(thick))/*
*/ (function y=x, range(0 1) lcolor(black) lpattern(-...-...)),/*
*/ legend(label(1 "USA") label(2 "China") label(3 "Ethiopa") label(4 "Guatemala") label(5 "Cambodia") label(6 "linear") ring (0) rows(3) position(4)) xtitle("p") ytitle("w(p)") xlab(0(0.1)1) ylab(0(0.1)1) yscale(alt)
graph export "/Users/nando/Dropbox/World Wide Prospect Theory/All_over_the_map/graph_weightingPT_examples_losses.eps", as(eps) preview(off)


**************************************************************
*** model 2: 
**************************************************************

local bio "female"
local macro "gdp_diff foreigner gini_z private opec"
ml model lf PT_expo (mu: probability high low equivalent = `macro' `bio') (ni:  =   `macro' `bio') (lambda:  =   `macro' `bio') (alpha:  =   `macro' `bio') (beta: =   `macro' `bio') (gamma:  =   `macro' `bio') (delta:  =   `macro' `bio') (noise: =   `macro' `bio' loss), technique(bfgs) cluster(subject_global) maximize init(mu:_cons=.05 ni:_cons=.05 lambda:_cons=1.5 alpha:_cons=.8 beta:_cons=.6  gamma:_cons=.8 delta:_cons=.6 noise:_cons=3.2) iterate(5000)
ml display

**************************************************************
*** model 3: 
**************************************************************

local countries "Australia Belgium Brazil Cambodia Chile China Colombia Costarica Czech Ethiopia France Germany Guatemala India Japan Kyrgyzstan Malaysia Nicaragua Nigeria Peru Poland Russia Saudi Southafrica Spain Thailand Tunisia UK Vietnam female"
local bio "female age_z height_z"
ml model lf PT_expo (mu: probability high low equivalent = `bio' `studies' `countries') (ni:  =  `bio' `studies' `countries') (lambda:  =  `bio' `studies' `countries') (alpha:  =  `bio' `studies' `countries') (beta: =  `bio' `studies' `countries') (gamma:  =  `bio' `studies' `countries') (delta:  =  `bio' `studies' `countries') (noise: =  `bio' `studies' `countries' loss), technique(bfgs) cluster(subject_global) maximize init(mu:_cons=.05 ni:_cons=.05 lambda:_cons=1.5 alpha:_cons=.8 beta:_cons=.6  gamma:_cons=.8 delta:_cons=.6 noise:_cons=3.2) iterate(5000)
ml display

**************************************************************
*** model 4: 
**************************************************************

local countries "Australia Belgium Brazil Cambodia Chile China Colombia Costarica Czech Ethiopia France Germany Guatemala India Japan Kyrgyzstan Malaysia Nicaragua Nigeria Peru Poland Russia Saudi Southafrica Spain Thailand Tunisia UK Vietnam female"
local bio "female age_z height_z"
local studies "gpa_z math natural medicine social humanities arts study_other"
ml model lf PT_expo (mu: probability high low equivalent = `bio' `studies' `countries') (ni:  =  `bio' `studies' `countries') (lambda:  =  `bio' `studies' `countries') (alpha:  =  `bio' `studies' `countries') (beta: =  `bio' `studies' `countries') (gamma:  =  `bio' `studies' `countries') (delta:  =  `bio' `studies' `countries') (noise: =  `bio' `studies' `countries' loss), technique(bfgs) cluster(subject_global) maximize init(mu:_cons=.05 ni:_cons=.05 lambda:_cons=1.5 alpha:_cons=.8 beta:_cons=.6  gamma:_cons=.8 delta:_cons=.6 noise:_cons=3.2) iterate(5000)
ml display

**********************************************************************
*******plot complete utilities for gains and losses and loss aversion
**********************************************************************

tw (function y=(1-exp(-0.04*x))/0.04, range(0 30) lcolor(dkgreen) lwidth(thick)) || (function y= -1.31*(1-exp(-0.001*abs(x)))/0.001, range(-20 0) lcolor(dkgreen) lwidth(thick))/*
*/ (function y=(1-exp(-0.02*x))/0.02, range(0 30) lcolor(yellow) lwidth(thick)) || (function y= -1.50*(1-exp(0.01*abs(x)))/-0.01, range(-20 0) lcolor(yellow) lwidth(thick))/*
*/ (function y=(1-exp(-0.01*x))/0.01, range(0 30) lcolor(orange) lpattern(-) lwidth(thick)) || (function y= -1.6*(1-exp(-0.01*abs(x)))/0.01, range(-20 0) lcolor(orange) lwidth(thick))/*
*/ (function y=(1-exp(-0.02*x))/0.02, range(0 30) lcolor(blue) lpattern(-) lwidth(thick)) || (function y= -2.23*(1-exp(-0.01*abs(x)))/0.01, range(-20 0) lcolor(blue) lpattern(-) lwidth(thick))/*
*/ (function y=(1-exp(-0.03*x))/0.03, range(0 30) lcolor(red) lpattern(-..-..) lwidth(thick)) || (function y= -2.38*(1-exp(-0.03*abs(x)))/0.03, range(-20 0) lcolor(red) lpattern(-..-..) lwidth(thick))/*
*/, legend(order(1 3 5 7 9) label(1 USA) label(3 China) label(5 Guatemala) label(7 Ethiopia) label(9 Nicaragua) ring (0) rows(5) position(5) bmargin(large))/*
*/ xlab(-20(5)30) ylab(-30(5)30) xtitle("X") ytitle("u(X)") yline(0, lc(black)) xline(0, lc(black))


****************
***estimate country by country
****************

gen PT_mu=.
gen PT_ni=.
gen PT_lambda=.
gen PT_alpha=.
gen PT_beta=.
gen PT_gamma=.
gen PT_delta=.
gen PT_sigma=.


forvalues i=1(1)30 {
display "country `i'"
capture ml model lf PT_expo (mu: probability high low equivalent = ) (ni:  = ) (lambda:  = ) (alpha:  = ) (beta: = ) (gamma:  = ) (delta:  = ) (noise: = loss) if country==`i', technique(bfgs) cluster(subject_global) maximize init(mu:_cons=.05 ni:_cons=.05 lambda:_cons=1.5 alpha:_cons=.8 beta:_cons=.6  gamma:_cons=.8 delta:_cons=.6 noise:_cons=3.2) iterate(5000)
ml display

matrix yaari_results = e(b)
scalar scalar_mu = el(yaari_results,1,1)
scalar scalar_ni = el(yaari_results,1,2)
scalar scalar_lambda = el(yaari_results,1,3)
scalar scalar_alpha = el(yaari_results,1,4)
scalar scalar_beta = el(yaari_results,1,5)
scalar scalar_gamma = el(yaari_results,1,6)
scalar scalar_delta = el(yaari_results,1,7)
scalar scalar_sigma = el(yaari_results,1,8)

replace PT_mu = scalar_mu if country == `i'
replace PT_ni = scalar_ni if country == `i'
replace PT_lambda = scalar_lambda if country == `i'
replace PT_alpha = scalar_alpha if country == `i'
replace PT_beta = scalar_beta if country == `i'
replace PT_gamma = scalar_gamma if country == `i'
replace PT_delta = scalar_delta if country == `i'
replace PT_sigma = scalar_sigma if country == `i'

estimates store yaari
}


****************
***graphs
****************


*******plot complete utilities for gains and losses and loss aversion

tw (function y=(1-exp(-0.05*x))/0.05, range(0 30) lcolor(dkgreen) lwidth(thick)) || (function y= -1.26*(1-exp(0.0001*abs(x)))/-0.0001, range(-20 0) lcolor(dkgreen) lwidth(thick))/*
*/ (function y=(1-exp(-0.026*x))/0.026, range(0 30) lcolor(yellow) lwidth(thick)) || (function y= -1.47*(1-exp(0.0001*abs(x)))/-0.0001, range(-20 0) lcolor(yellow) lwidth(thick))/*
*/ (function y=(1-exp(-0.017*x))/0.017, range(0 30) lcolor(orange) lpattern(-) lwidth(thick)) || (function y= -1.57*(1-exp(-0.014*abs(x)))/0.014, range(-20 0) lcolor(orange) lwidth(thick))/*
*/ (function y=(1-exp(-0.019*x))/0.019, range(0 30) lcolor(blue) lpattern(-) lwidth(thick)) || (function y= -2.22*(1-exp(-0.007*abs(x)))/0.007, range(-20 0) lcolor(blue) lpattern(-) lwidth(thick))/*
*/ (function y=(1-exp(-0.033*x))/0.033, range(0 30) lcolor(red) lpattern(-..-..) lwidth(thick)) || (function y= -2.37*(1-exp(-0.029*abs(x)))/0.029, range(-20 0) lcolor(red) lpattern(-..-..) lwidth(thick))/*
*/, legend(order(1 3 5 7 9) label(1 USA) label(3 China) label(5 Guatemala) label(7 Ethiopia) label(9 Nicaragua) ring (0) rows(5) position(5) bmargin(large))/*
*/ xlab(-20(5)30) ylab(-30(5)30) xtitle("X") ytitle("u(X)") yline(0, lc(black)) xline(0, lc(black))

 
